Welcome to ClientVPS Mirrors

Help for package QHOT
Type: Package
Title: QTL Hotspot Detection
Version: 0.1.0
Author: ManHsia Yang
Maintainer: ManHsia Yang <ymh@tari.gov.tw>
Description: This function produces both the numerical and graphical summaries of the QTL hotspot detection in the genomes that are available on the worldwide web including the flanking markers of QTLs.
License: GPL (≥ 3)
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.1.1
NeedsCompilation: no
Packaged: 2019-01-04 06:23:23 UTC; ymh
Repository: CRAN
Date/Publication: 2019-01-08 17:40:05 UTC

QTL Hotspot Detection

Description

This function produces both the numerical and graphical summaries of the QTL hotspot detection in the genomes that are available on the worldwide web including the flanking markers of QTLs. Man-Hsia Yang, Dong-Hong Wu, Chen-Hung Kao. 2019. A Statistical Procedure for Genome-wide Detection of QTL Hotspots Using Public Databases with Application to Rice. G3-Genes Genom Genet DOI: 10.1534/g3.118.200922.

Usage

QHOT(DataQTL, DataCrop, ScanStep, NH, NP)

Arguments

DataQTL

a data-frame of values for QTL information including the trait names, which chromosomes localized, the left and right flanking marker positions of QTLs for the first to fourth columns, respectively.

DataCrop

a data-frame of values for chromosome information consisting of the names, center positions and lengths of chromosomes for the first to third columns, respectively.

ScanStep

a value for the length of every bin.

NH

a value for the number of spurious hotspots in the proposed method.

NP

a value for permutation times to calculate the threshold.

References

Man-Hsia Yang, Dong-Hong Wu, Chen-Hung Kao. 2019. A Statistical Procedure for Genome-wide Detection of QTL Hotspots Using Public Databases with Application to Rice. G3-Genes Genom Genet DOI: 10.1534/g3.118.200922.

Examples

Trait<-paste("t",sample(1:9,100,replace=TRUE,prob=c(2,rep(1,8))/10),sep="")
chr<-1
L<-sample(seq(0,90,by=10),100,replace=TRUE,prob=c(0.5,0.5,5.5,rep(0.5,7))/10)
R<-L+sample(c(0.5,1,5,10,50),100,replace=TRUE)
R[R>100]<-100
DataQTL.t<-data.frame(Trait,chr,L,R)
DataCrop.t<-data.frame(chr=1,center=75,length=100)
QHOT(DataQTL.t, DataCrop.t, ScanStep=0.5, NH=1, NP=1000)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.